@@ -23,9 +23,9 @@
 #define __EPHY_EPIPHANY_H_INSIDE__
 
 /* From GTK_CHECK_VERSION */
-#define EPHY_MAJOR_VERSION (2)
-#define EPHY_MINOR_VERSION (30)
-#define EPHY_MICRO_VERSION (6)
+#define EPHY_MAJOR_VERSION (3)
+#define EPHY_MINOR_VERSION (4)
+#define EPHY_MICRO_VERSION (3)
 
 #define EPHY_CHECK_VERSION(major, minor, micro)\
   (EPHY_MAJOR_VERSION > (major) || \
@@ -38,10 +38,10 @@
 #include <epiphany/ephy-bookmarks.h>
 #include <epiphany/ephy-bookmarks-type-builtins.h>
 #include <epiphany/ephy-dialog.h>
+#include <epiphany/ephy-download.h>
 #include <epiphany/ephy-embed-container.h>
 #include <epiphany/ephy-embed-event.h>
 #include <epiphany/ephy-embed.h>
-#include <epiphany/ephy-embed-persist.h>
 #include <epiphany/ephy-embed-prefs.h>
 #include <epiphany/ephy-embed-shell.h>
 #include <epiphany/ephy-embed-single.h>
@@ -49,7 +49,6 @@
 #include <epiphany/ephy-embed-utils.h>
 #include <epiphany/ephy-extension.h>
 #include <epiphany/ephy-extensions-manager.h>
-#include <epiphany/ephy-history.h>
 #include <epiphany/ephy-lib-type-builtins.h>
 #include <epiphany/ephy-link.h>
 #include <epiphany/ephy-loader.h>
@@ -60,7 +59,6 @@
 #include <epiphany/ephy-session.h>
 #include <epiphany/ephy-shell.h>
 #include <epiphany/ephy-state.h>
-#include <epiphany/ephy-statusbar.h>
 #include <epiphany/ephy-type-builtins.h>
 #include <epiphany/ephy-window.h>
 
